@@ -267,8 +267,9 @@ datBarplot <- function(x,
   datx <- DT_NAto0(datx, yvar)
  
   ## Divide by 
-  if (!is.null(divideby))
+  if (!is.null(divideby)) {
     datx[, (yvar) := lapply(.SD, function(x) x / dividebynum), .SDcols=yvar]
+  }
 
   ## sevar/psevar
   ######################
@@ -503,7 +504,7 @@ datBarplot <- function(x,
       mar[2] <- xlinenum + (10/xlinenum)		## left mar
       mar[4] <- 2.5						## right mar
     } else {
-      mar[1] <- xlinenum * cex.names + 2.5		## bottom mar
+      mar[1] <- xlinenum * cex.names + 2.8		## bottom mar
       mar[2] <- ylinenum + 1.6				## left mar
       mar[4] <- 0.5						## right mar
     }
@@ -572,7 +573,8 @@ datBarplot <- function(x,
         }
       }     
     } else {
-      xmat <- tapply(datxbp[,yvar, with=FALSE], list(datxbp[[xvar]], datxbp[[grpvar]]), I)
+      xmat <- tapply(datxbp[,yvar, with=FALSE][[1]], 
+			list(datxbp[[xvar]], datxbp[[grpvar]]), I)
       xmat[is.na(xmat)] <- 0
 
       if (addlegend) {
@@ -609,9 +611,16 @@ datBarplot <- function(x,
     ## ADD ERROR BARS
     ######################################################
     if (errbars) {
-      if(length(yvar) == 1){
-        y <- datxbp[[yvar]]
-        lower <- upper <- datxbp[[sevar]]
+      if (length(yvar) == 1) {
+        if (!is.null(grpvar)) {
+          y <- xmat
+          semat <- tapply(datxbp[,sevar, with=FALSE][[1]], 
+					list(as.character(datxbp[[xvar]]), 															as.character(datxbp[[grpvar]])), I)
+          lower <- upper <- semat
+        } else {
+          y <- datxbp[[yvar]]
+          lower <- upper <- datxbp[[sevar]]
+        }
       } else {
         y <- xmat
         semat <- as.matrix(t(datxbp[,sevar, with=FALSE]))
