@@ -80,6 +80,7 @@
 #' model. 
 #' @param predfac String vector. Name(s) of factor predictor variables to use
 #' in model. Names will change in output depending on number of categories.
+#' @param returndata Logical. If TRUE, returns data objects.
 #' @param savedata Logical. If TRUE, saves table(s) to outfolder. 
 #' @param saveobj Logical. If TRUE, saves returned list object to outfolder.
 #' @param objnm String. Name of *.rds object.
@@ -192,6 +193,7 @@ modSApop <- function(popType="VOL",
                      dunitzonal = NULL, 
                      prednames = NULL, 
                      predfac = NULL, 
+                     returndata = TRUE,
                      savedata = FALSE, 
                      saveobj = FALSE, 
                      objnm = "SApopdat", 
@@ -349,7 +351,7 @@ modSApop <- function(popType="VOL",
   } 
 
   if (saveobj) {
-    outobj_fmtlst <- c('rds', 'rda', 'llo')
+    outobj_fmtlst <- c('rds', 'rda')
     outobj_fmt <- pcheck.varchar(var2check=outobj_fmt, varnm="outobj_fmt", gui=gui,
 		checklst=outobj_fmtlst, caption="outobj_fmt", multiple=FALSE, stopifnull=TRUE)
 
@@ -373,7 +375,7 @@ modSApop <- function(popType="VOL",
   popevalid <- as.character(evalid)
   if (!is.null(evalid)) {
     substr(popevalid, nchar(popevalid)-1, nchar(popevalid)) <- 
-		FIESTA::ref_popType[FIESTA::ref_popType$popType %in% popType, "EVAL_TYP_CD"]
+		FIESTAutils::ref_popType[FIESTAutils::ref_popType$popType %in% popType, "EVAL_TYP_CD"]
   } 
 
   ###################################################################################
@@ -701,22 +703,14 @@ modSApop <- function(popType="VOL",
   ## Save list object
   ##################################################################
   if (saveobj) {
-    if (getext(objfn) == "llo") {
-      if (append_layer) {
-        message("appending list object to: ", objfn)
-        largeList::saveList(returnlst, file=objfn, append=append_layer, compress=TRUE)
-      } else {
-        message("saving list object to: ", objfn)
-        largeList::saveList(returnlst, file=objfn, compress=TRUE)
-      }
-    } else if (getext(objfn) == "rds") {
+    if (getext(objfn) == "rds") {
       message("saving list object to: ", objfn)
       saveRDS(returnlst, objfn)
     } else if (getext(objfn) == "rda") {
       message("saving list object to: ", objfn)
       save(returnlst, objfn)
     } else {
-      message("invalid object name... must end in: ", toString(c("rds", "rda", "llo")))
+      message("invalid object name... must end in: ", toString(c("rds", "rda")))
     } 
   } 
 
@@ -801,5 +795,9 @@ modSApop <- function(popType="VOL",
                               add_layer=TRUE))
   }
 
-  return(returnlst)
+  if (returndata) {
+    return(returnlst)
+  } 
+  rm(returnlst)
+  gc()
 }
