@@ -325,12 +325,7 @@ spGetAuxiliary <- function(xyplt = NULL,
                                   xy.uniqueid=uniqueid, 
                                   xvar=xvar, 
                                   yvar=yvar,
-                                  xy.crs=xy.crs,
-                                  prj=prj,
-                                  datum=datum,
-                                  zone=zone,
-                                  zoneS=zoneS,
-                                  aea.param=aea.param)
+                                  xy.crs=xy.crs)
     } else {
       ## GET uniqueid
       sppltnames <- names(sppltx)
@@ -377,7 +372,7 @@ spGetAuxiliary <- function(xyplt = NULL,
 
   ## Check continuous rasters
   ###################################################################
-  rastlst.contfn <- tryCatch(suppressWarnings(getrastlst.rgdal(rastlst.cont, 
+  rastlst.contfn <- tryCatch(suppressWarnings(getrastlst(rastlst.cont, 
 	rastfolder, quiet=TRUE, gui=gui)),
      	 	error=function(e) {
 			      message(e, "\n")
@@ -427,7 +422,7 @@ spGetAuxiliary <- function(xyplt = NULL,
     ## Transform aspect 
     if (asptransform) {
       ## Check aspect raster
-      rast.aspfn <- getrastlst.rgdal(rast.asp, rastfolder, gui=gui)  
+      rast.aspfn <- getrastlst(rast.asp, rastfolder, gui=gui)  
 
       if (is.null(rast.aspfn)) {
         stop("must identify aspect raster in rastlst.contfn using rast.asp")
@@ -443,7 +438,7 @@ spGetAuxiliary <- function(xyplt = NULL,
  
   ## Check categorical rasters
   ###################################################################
-  rastlst.catfn <- tryCatch(suppressWarnings(getrastlst.rgdal(rastlst.cat, 
+  rastlst.catfn <- tryCatch(suppressWarnings(getrastlst(rastlst.cat, 
 	rastfolder, quiet=TRUE, gui=gui)),
      	 	error=function(e) {
 			      message(e, "\n")
@@ -478,7 +473,7 @@ spGetAuxiliary <- function(xyplt = NULL,
     }
 
     ## Check raster for lookup table
-    rast.lutfn <- suppressWarnings(getrastlst.rgdal(rast.lut, rastfolder, gui=gui))
+    rast.lutfn <- suppressWarnings(getrastlst(rast.lut, rastfolder, gui=gui))
     
     if (!is.null(rast.lutfn)) {
       if (length(rast.lutfn) > 1) 
